royal\_mail\_rest\_api package
==============================

Submodules
----------

royal\_mail\_rest\_api.api module
---------------------------------

.. automodule:: royal_mail_rest_api.api
    :members:
    :undoc-members:
    :show-inheritance:

royal\_mail\_rest\_api.errors module
------------------------------------

.. automodule:: royal_mail_rest_api.errors
    :members:
    :undoc-members:
    :show-inheritance:

royal\_mail\_rest\_api.example module
-------------------------------------

.. automodule:: royal_mail_rest_api.example
    :members:
    :undoc-members:
    :show-inheritance:

royal\_mail\_rest\_api.get\_credentials module
----------------------------------------------

.. automodule:: royal_mail_rest_api.get_credentials
    :members:
    :undoc-members:
    :show-inheritance:

royal\_mail\_rest\_api.shipping module
--------------------------------------

.. automodule:: royal_mail_rest_api.shipping
    :members:
    :undoc-members:
    :show-inheritance:

royal\_mail\_rest\_api.tools module
-----------------------------------

.. automodule:: royal_mail_rest_api.tools
    :members:
    :undoc-members:
    :show-inheritance:

royal\_mail\_rest\_api.tracking module
--------------------------------------

.. automodule:: royal_mail_rest_api.tracking
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: royal_mail_rest_api
    :members:
    :undoc-members:
    :show-inheritance:
